# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class VendorPurchase(BaseModel):
    """
    VendorPurchase
    """ # noqa: E501
    vendor_id: Optional[StrictStr] = Field(default=None, description="(v1.0) The vendorId property for the Dynamics 365 Business Central vendorPurchase entity", alias="vendorId")
    vendor_number: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="(v1.0) The vendorNumber property for the Dynamics 365 Business Central vendorPurchase entity", alias="vendorNumber")
    name: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="(v1.0) The name property for the Dynamics 365 Business Central vendorPurchase entity")
    total_purchase_amount: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="(v1.0) The totalPurchaseAmount property for the Dynamics 365 Business Central vendorPurchase entity", alias="totalPurchaseAmount")
    date_filter_filter_only: Optional[datetime] = Field(default=None, description="(v1.0) The dateFilter_FilterOnly property for the Dynamics 365 Business Central vendorPurchase entity", alias="dateFilter_FilterOnly")
    __properties: ClassVar[List[str]] = ["vendorId", "vendorNumber", "name", "totalPurchaseAmount", "dateFilter_FilterOnly"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VendorPurchase from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if total_purchase_amount (nullable) is None
        # and model_fields_set contains the field
        if self.total_purchase_amount is None and "total_purchase_amount" in self.model_fields_set:
            _dict['totalPurchaseAmount'] = None

        # set to None if date_filter_filter_only (nullable) is None
        # and model_fields_set contains the field
        if self.date_filter_filter_only is None and "date_filter_filter_only" in self.model_fields_set:
            _dict['dateFilter_FilterOnly'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VendorPurchase from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "vendorId": obj.get("vendorId"),
            "vendorNumber": obj.get("vendorNumber"),
            "name": obj.get("name"),
            "totalPurchaseAmount": obj.get("totalPurchaseAmount"),
            "dateFilter_FilterOnly": obj.get("dateFilter_FilterOnly")
        })
        return _obj


