# coding: utf-8

"""
(v2.0) Dynamics 365 Business Central

(v2.0) Business Central Standard APIs

The version of the OpenAPI document: 2.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from setuptools import find_packages, setup  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "pybusinesscentral"
VERSION = "3.3.0"
PYTHON_REQUIRES = ">= 3.9"
REQUIRES = [
    "urllib3 >= 2.1.0, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="(v2.0) Dynamics 365 Business Central",
    author="Uptick",
    author_email="support@uptickhq.com",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "(v2.0) Dynamics 365 Business Central"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description_content_type="text/markdown",
    long_description="""\
    (v2.0) Business Central Standard APIs
    """,  # noqa: E501
    package_data={"pybusinesscentral": ["py.typed"]},
)
