# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.model.aged_accounts_payable import AgedAccountsPayable

class TestAgedAccountsPayable(unittest.TestCase):
    """AgedAccountsPayable unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AgedAccountsPayable:
        """Test AgedAccountsPayable
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AgedAccountsPayable`
        """
        model = AgedAccountsPayable()
        if include_optional:
            return AgedAccountsPayable(
                vendor_id = '',
                vendor_number = '',
                name = '',
                currency_code = '',
                balance_due = 1.337,
                current_amount = 1.337,
                period1_amount = 1.337,
                period2_amount = 1.337,
                period3_amount = 1.337,
                aged_as_of_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                period_length_filter = ''
            )
        else:
            return AgedAccountsPayable(
        )
        """

    def testAgedAccountsPayable(self):
        """Test AgedAccountsPayable"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
