# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.model.employee import Employee

class TestEmployee(unittest.TestCase):
    """Employee unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Employee:
        """Test Employee
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Employee`
        """
        model = Employee()
        if include_optional:
            return Employee(
                id = '',
                number = '',
                display_name = '',
                given_name = '',
                middle_name = '',
                surname = '',
                job_title = '',
                address = pybusinesscentral.model.postaladdresstype.postaladdresstype(
                    street = '', 
                    city = '', 
                    state = '', 
                    country_letter_code = '', 
                    postal_code = '', 
                    customer_financial_details = [
                        pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                            id = '', 
                            number = '', 
                            balance = 1.337, 
                            total_sales_excluding_tax = 1.337, 
                            overdue_amount = 1.337, )
                        ], 
                    picture = [
                        pybusinesscentral.model.picture.picture(
                            id = '', 
                            width = 56, 
                            height = 56, 
                            content_type = '', 
                            content@odata/media_edit_link = '', 
                            content@odata/media_read_link = '', )
                        ], 
                    default_dimensions = [
                        pybusinesscentral.model.default_dimensions.defaultDimensions(
                            parent_id = '', 
                            dimension_id = '', 
                            dimension_code = '', 
                            dimension_value_id = '', 
                            dimension_value_code = '', 
                            posting_validation = '', 
                            account = pybusinesscentral.model.account.account(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                category = '', 
                                sub_category = '', 
                                blocked = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            dimension = pybusinesscentral.model.dimension.dimension(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                dimension_values = [
                                    pybusinesscentral.model.dimension_value.dimensionValue(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                    ], ), 
                            dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                        ], 
                    currency = pybusinesscentral.model.currency.currency(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        symbol = '', 
                        amount_decimal_places = '', 
                        amount_rounding_precision = 1.337, 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        due_date_calculation = '', 
                        discount_date_calculation = '', 
                        discount_percent = 1.337, 
                        calculate_discount_on_credit_memos = True, 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    payment_method = pybusinesscentral.model.payment_method.paymentMethod(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
                phone_number = '',
                mobile_phone = '',
                email = '',
                personal_email = '',
                employment_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                termination_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                status = '',
                birth_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                statistics_group_code = '',
                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                picture = [
                    pybusinesscentral.model.picture.picture(
                        id = '', 
                        width = 56, 
                        height = 56, 
                        content_type = '', 
                        content@odata/media_edit_link = '', 
                        content@odata/media_read_link = '', )
                    ],
                default_dimensions = [
                    pybusinesscentral.model.default_dimensions.defaultDimensions(
                        parent_id = '', 
                        dimension_id = '', 
                        dimension_code = '', 
                        dimension_value_id = '', 
                        dimension_value_code = '', 
                        posting_validation = '', 
                        account = pybusinesscentral.model.account.account(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            category = '', 
                            sub_category = '', 
                            blocked = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        dimension = pybusinesscentral.model.dimension.dimension(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            dimension_values = [
                                pybusinesscentral.model.dimension_value.dimensionValue(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                ], ), 
                        dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                time_registration_entries = [
                    pybusinesscentral.model.time_registration_entry.timeRegistrationEntry(
                        id = '', 
                        employee_id = '', 
                        employee_number = '', 
                        job_id = '', 
                        job_number = '', 
                        absence = '', 
                        line_number = 56, 
                        date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        quantity = 1.337, 
                        status = '', 
                        unit_of_measure_id = '', 
                        unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                            code = '', 
                            display_name = '', 
                            symbol = '', 
                            unit_conversion = pybusinesscentral.model.itemunitofmeasureconversiontype.itemunitofmeasureconversiontype(
                                to_unit_of_measure = '', 
                                from_to_conversion_rate = 1.337, 
                                picture = [
                                    pybusinesscentral.model.picture.picture(
                                        id = '', 
                                        width = 56, 
                                        height = 56, 
                                        content_type = '', 
                                        content@odata/media_edit_link = '', 
                                        content@odata/media_read_link = '', )
                                    ], 
                                default_dimensions = [
                                    pybusinesscentral.model.default_dimensions.defaultDimensions(
                                        parent_id = '', 
                                        dimension_id = '', 
                                        dimension_code = '', 
                                        dimension_value_id = '', 
                                        dimension_value_code = '', 
                                        posting_validation = '', 
                                        account = pybusinesscentral.model.account.account(
                                            id = '', 
                                            number = '', 
                                            display_name = '', 
                                            category = '', 
                                            sub_category = '', 
                                            blocked = True, 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                        dimension = pybusinesscentral.model.dimension.dimension(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            dimension_values = [
                                                pybusinesscentral.model.dimension_value.dimensionValue(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                ], ), 
                                        dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                    ], 
                                item_category = pybusinesscentral.model.item_category.itemCategory(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                            picture = [
                                pybusinesscentral.model.picture.picture(
                                    id = '', 
                                    width = 56, 
                                    height = 56, 
                                    content_type = '', 
                                    content@odata/media_edit_link = '', 
                                    content@odata/media_read_link = '', )
                                ], 
                            default_dimensions = [
                                pybusinesscentral.model.default_dimensions.defaultDimensions(
                                    parent_id = '', 
                                    dimension_id = '', 
                                    dimension_code = '', 
                                    dimension_value_id = '', 
                                    dimension_value_code = '', 
                                    posting_validation = '', )
                                ], 
                            item_category = pybusinesscentral.model.item_category.itemCategory(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        dimensions = [
                            null
                            ], 
                        last_modfied_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        project = pybusinesscentral.model.project.project(
                            id = '', 
                            number = '', 
                            display_name = '', ), )
                    ]
            )
        else:
            return Employee(
        )
        """

    def testEmployee(self):
        """Test Employee"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
